==> sdd.debin-jar-0.2.21.jar: ar/com/sdd/debin/io/apibancos/DebitoRequest.java <==
package ar.com.sdd.debin.io.apibancos;

import ar.com.sdd.debin.entity.*;
import ar.com.sdd.debin.util.ManyMillisecondsDateDeserializer;
import ar.com.sdd.debin.util.ManyMillisecondsDateSerializer;
import javax.json.bind.annotation.JsonbDateFormat;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import javax.json.bind.annotation.JsonbTypeDeserializer;
import javax.json.bind.annotation.JsonbTypeSerializer;

import javax.json.bind.annotation.JsonbNillable;
import java.util.Date;

@JsonIgnoreProperties(ignoreUnknown = true)
@JsonbNillable
public class DebitoRequest {

    private Objeto objeto;
    private Credito credito;
    private Debito debito;
    private Importe importe;
    private Integer mismoTitular;

    @JsonbTypeDeserializer(ManyMillisecondsDateDeserializer.class)
    @JsonbTypeSerializer(ManyMillisecondsDateSerializer.class)
    private Date fechaHora;

    @JsonbDateFormat("yyyy-MM-dd")
    private Date fechaNegocio;
    private String ori_trx;
    private String ori_terminal;
    private String ori_adicional;
    private Evaluacion evaluacion;

    public Objeto getObjeto() {
        return objeto;
    }

    public void setObjeto(Objeto objeto) {
        this.objeto = objeto;
    }

    public Credito getCredito() {
        return credito;
    }

    public void setCredito(Credito credito) {
        this.credito = credito;
    }

    public Debito getDebito() {
        return debito;
    }

    public void setDebito(Debito debito) {
        this.debito = debito;
    }

    public Importe getImporte() {
        return importe;
    }

    public void setImporte(Importe importe) {
        this.importe = importe;
    }

    public Date getFechaHora() {
        return fechaHora;
    }

    public void setFechaHora(Date fechaHora) {
        this.fechaHora = fechaHora;
    }

    public Date getFechaNegocio() {
        return fechaNegocio;
    }

    public void setFechaNegocio(Date fechaNegocio) {
        this.fechaNegocio = fechaNegocio;
    }

    public String getOri_trx() {
        return ori_trx;
    }

    public void setOri_trx(String ori_trx) {
        this.ori_trx = ori_trx;
    }

    public String getOri_terminal() {
        return ori_terminal;
    }

    public void setOri_terminal(String ori_terminal) {
        this.ori_terminal = ori_terminal;
    }

    public String getOri_adicional() {
        return ori_adicional;
    }

    public void setOri_adicional(String ori_adicional) {
        this.ori_adicional = ori_adicional;
    }

    public Evaluacion getEvaluacion() {
        return evaluacion;
    }

    public void setEvaluacion(Evaluacion evaluacion) {
        this.evaluacion = evaluacion;
    }

    public Integer getMismoTitular() {
        return mismoTitular;
    }

    public void setMismoTitular(Integer mismoTitular) {
        this.mismoTitular = mismoTitular;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        DebitoRequest that = (DebitoRequest) o;

        if (objeto != null ? !objeto.equals(that.objeto) : that.objeto != null) return false;
        if (credito != null ? !credito.equals(that.credito) : that.credito != null) return false;
        if (debito != null ? !debito.equals(that.debito) : that.debito != null) return false;
        if (importe != null ? !importe.equals(that.importe) : that.importe != null) return false;
        if (mismoTitular != null ? !mismoTitular.equals(that.mismoTitular) : that.mismoTitular != null) return false;
        if (fechaHora != null ? !fechaHora.equals(that.fechaHora) : that.fechaHora != null) return false;
        if (fechaNegocio != null ? !fechaNegocio.equals(that.fechaNegocio) : that.fechaNegocio != null) return false;
        if (ori_trx != null ? !ori_trx.equals(that.ori_trx) : that.ori_trx != null) return false;
        if (ori_terminal != null ? !ori_terminal.equals(that.ori_terminal) : that.ori_terminal != null) return false;
        if (ori_adicional != null ? !ori_adicional.equals(that.ori_adicional) : that.ori_adicional != null) return false;
        return evaluacion != null ? evaluacion.equals(that.evaluacion) : that.evaluacion == null;
    }

    @Override
    public int hashCode() {
        int result = objeto != null ? objeto.hashCode() : 0;
        result = 31 * result + (credito != null ? credito.hashCode() : 0);
        result = 31 * result + (debito != null ? debito.hashCode() : 0);
        result = 31 * result + (importe != null ? importe.hashCode() : 0);
        result = 31 * result + (mismoTitular != null ? mismoTitular.hashCode() : 0);
        result = 31 * result + (fechaHora != null ? fechaHora.hashCode() : 0);
        result = 31 * result + (fechaNegocio != null ? fechaNegocio.hashCode() : 0);
        result = 31 * result + (ori_trx != null ? ori_trx.hashCode() : 0);
        result = 31 * result + (ori_terminal != null ? ori_terminal.hashCode() : 0);
        result = 31 * result + (ori_adicional != null ? ori_adicional.hashCode() : 0);
        result = 31 * result + (evaluacion != null ? evaluacion.hashCode() : 0);
        return result;
    }

    @Override
    public String toString() {
        return "DebitoRequest [" +
                "objeto=" + objeto +
                ", credito=" + credito +
                ", debito=" + debito +
                ", importe=" + importe +
                ", mismoTitular=" + mismoTitular +
                ", fechaHora=" + fechaHora +
                ", fechaNegocio=" + fechaNegocio +
                ", ori_trx=" + ori_trx +
                ", ori_terminal=" + ori_terminal +
                ", ori_adicional=" + ori_adicional +
                ", evaluacion=" + evaluacion +
                ']';
    }
}

==> sdd.debin-jar-0.3.1.jar: ar/com/sdd/debin/io/apibancos/DebitoRequest.java <==
package ar.com.sdd.debin.io.apibancos;

import ar.com.sdd.debin.entity.*;
import ar.com.sdd.debin.util.ManyMillisecondsDateDeserializer;
import ar.com.sdd.debin.util.ManyMillisecondsDateSerializer;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;



import com.fasterxml.jackson.annotation.*;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;

import java.util.Date;

@JsonIgnoreProperties(ignoreUnknown = true)
@JsonInclude(JsonInclude.Include.NON_NULL)
public class DebitoRequest {

    private Objeto objeto;
    private Credito credito;
    private Debito debito;
    private Importe importe;
    private Integer mismoTitular;

    @JsonDeserialize(using = ManyMillisecondsDateDeserializer.class)
    @JsonSerialize(using = ManyMillisecondsDateSerializer.class)
    private Date fechaHora;

    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT-03:00")
    private Date fechaNegocio;
    private String ori_trx;
    private String ori_terminal;
    private String ori_adicional;
    private Evaluacion evaluacion;

    public Objeto getObjeto() {
        return objeto;
    }

    public void setObjeto(Objeto objeto) {
        this.objeto = objeto;
    }

    public Credito getCredito() {
        return credito;
    }

    public void setCredito(Credito credito) {
        this.credito = credito;
    }

    public Debito getDebito() {
        return debito;
    }

    public void setDebito(Debito debito) {
        this.debito = debito;
    }

    public Importe getImporte() {
        return importe;
    }

    public void setImporte(Importe importe) {
        this.importe = importe;
    }

    public Date getFechaHora() {
        return fechaHora;
    }

    public void setFechaHora(Date fechaHora) {
        this.fechaHora = fechaHora;
    }

    public Date getFechaNegocio() {
        return fechaNegocio;
    }

    public void setFechaNegocio(Date fechaNegocio) {
        this.fechaNegocio = fechaNegocio;
    }

    public String getOri_trx() {
        return ori_trx;
    }

    public void setOri_trx(String ori_trx) {
        this.ori_trx = ori_trx;
    }

    public String getOri_terminal() {
        return ori_terminal;
    }

    public void setOri_terminal(String ori_terminal) {
        this.ori_terminal = ori_terminal;
    }

    public String getOri_adicional() {
        return ori_adicional;
    }

    public void setOri_adicional(String ori_adicional) {
        this.ori_adicional = ori_adicional;
    }

    public Evaluacion getEvaluacion() {
        return evaluacion;
    }

    public void setEvaluacion(Evaluacion evaluacion) {
        this.evaluacion = evaluacion;
    }

    public Integer getMismoTitular() {
        return mismoTitular;
    }

    public void setMismoTitular(Integer mismoTitular) {
        this.mismoTitular = mismoTitular;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        DebitoRequest that = (DebitoRequest) o;

        if (objeto != null ? !objeto.equals(that.objeto) : that.objeto != null) return false;
        if (credito != null ? !credito.equals(that.credito) : that.credito != null) return false;
        if (debito != null ? !debito.equals(that.debito) : that.debito != null) return false;
        if (importe != null ? !importe.equals(that.importe) : that.importe != null) return false;
        if (mismoTitular != null ? !mismoTitular.equals(that.mismoTitular) : that.mismoTitular != null) return false;
        if (fechaHora != null ? !fechaHora.equals(that.fechaHora) : that.fechaHora != null) return false;
        if (fechaNegocio != null ? !fechaNegocio.equals(that.fechaNegocio) : that.fechaNegocio != null) return false;
        if (ori_trx != null ? !ori_trx.equals(that.ori_trx) : that.ori_trx != null) return false;
        if (ori_terminal != null ? !ori_terminal.equals(that.ori_terminal) : that.ori_terminal != null) return false;
        if (ori_adicional != null ? !ori_adicional.equals(that.ori_adicional) : that.ori_adicional != null) return false;
        return evaluacion != null ? evaluacion.equals(that.evaluacion) : that.evaluacion == null;
    }

    @Override
    public int hashCode() {
        int result = objeto != null ? objeto.hashCode() : 0;
        result = 31 * result + (credito != null ? credito.hashCode() : 0);
        result = 31 * result + (debito != null ? debito.hashCode() : 0);
        result = 31 * result + (importe != null ? importe.hashCode() : 0);
        result = 31 * result + (mismoTitular != null ? mismoTitular.hashCode() : 0);
        result = 31 * result + (fechaHora != null ? fechaHora.hashCode() : 0);
        result = 31 * result + (fechaNegocio != null ? fechaNegocio.hashCode() : 0);
        result = 31 * result + (ori_trx != null ? ori_trx.hashCode() : 0);
        result = 31 * result + (ori_terminal != null ? ori_terminal.hashCode() : 0);
        result = 31 * result + (ori_adicional != null ? ori_adicional.hashCode() : 0);
        result = 31 * result + (evaluacion != null ? evaluacion.hashCode() : 0);
        return result;
    }

    @Override
    public String toString() {
        return "DebitoRequest [" +
                "objeto=" + objeto +
                ", credito=" + credito +
                ", debito=" + debito +
                ", importe=" + importe +
                ", mismoTitular=" + mismoTitular +
                ", fechaHora=" + fechaHora +
                ", fechaNegocio=" + fechaNegocio +
                ", ori_trx=" + ori_trx +
                ", ori_terminal=" + ori_terminal +
                ", ori_adicional=" + ori_adicional +
                ", evaluacion=" + evaluacion +
                ']';
    }
}
